@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: MonadCatchIO-mtl
-version: 0.3.0.4
-id: MonadCatchIO-mtl-0.3.0.4-71e86801e5931fd974633b3c7e6e1486
+version: 0.3.0.5
+id: MonadCatchIO-mtl-0.3.0.5-50eb20252600070062edde5090a7ae72
 
 license: BSD3
 copyright:
@@ -9,6 +9,7 @@ maintainer: jcpetruzza@gmail.com
 stability:
 homepage: http://darcsden.com/jcpetruzza/MonadCatchIO-mtl
 package-url:
+synopsis: Monad-transformer version of the Control.Exception module
 description: Provides a monad-transformer version of the @Control.Exception.catch@
              function. For this, it defines the @MonadCatchIO@ class, a subset of
              @MonadIO@. It defines proper instances for most monad transformers in
@@ -19,21 +20,22 @@ pkgpath: devel/hs-MonadCatchIO-mtl
 exposed: True
 exposed-modules: Control.Monad.CatchIO
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/MonadCatchIO-mtl-0.3.0.4
-library-dirs: /usr/local/lib/ghc/MonadCatchIO-mtl-0.3.0.4
-hs-libraries: HSMonadCatchIO-mtl-0.3.0.4
+trusted: False
+import-dirs: /usr/local/lib/ghc/MonadCatchIO-mtl-0.3.0.5
+library-dirs: /usr/local/lib/ghc/MonadCatchIO-mtl-0.3.0.5
+hs-libraries: HSMonadCatchIO-mtl-0.3.0.5
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
-         extensible-exceptions-0.1.1.2-d8c5b906654260efd7249f497d17a831
-         mtl-2.0.1.0-3e464329054b7660133198d73c31aca5
+depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
+         extensible-exceptions-0.1.1.4-3d9bd197c43329612c640f24179a7f19
+         mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-MonadCatchIO-mtl-0.3.0.4/html/MonadCatchIO-mtl.haddock
-haddock-html: /usr/local/share/doc/hs-MonadCatchIO-mtl-0.3.0.4/html
+haddock-interfaces: /usr/local/share/doc/hs-MonadCatchIO-mtl-0.3.0.5/html/MonadCatchIO-mtl.haddock
+haddock-html: /usr/local/share/doc/hs-MonadCatchIO-mtl-0.3.0.5/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
